@@ -76,8 +76,10 @@ import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.PGPEncryp
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.RedirectActionCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.RejectActionCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.RemoveFlagActionCommandParser;
+import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.SetFlagActionCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.StopActionCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.action.VacationActionCommandParser;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link ActionCommandRuleFieldMapper}
@@ -103,6 +105,7 @@ public class ActionCommandRuleFieldMapper implements RuleFieldMapper {
         p.put(Commands.STOP.getJsonName(), new StopActionCommandParser());
         p.put(Commands.VACATION.getJsonName(), new VacationActionCommandParser());
         p.put(Commands.ENOTIFY.getJsonName(), new EnotifyActionCommandParser());
+        p.put(Commands.SETFLAG.getJsonName(), new SetFlagActionCommandParser());
         p.put(Commands.ADDFLAG.getJsonName(), new AddFlagActionCommandParser());
         p.put(Commands.REMOVEFLAG.getJsonName(), new RemoveFlagActionCommandParser());
         p.put(Commands.PGP_ENCRYPT.getJsonName(), new PGPEncryptActionCommandParser());
@@ -159,7 +162,7 @@ public class ActionCommandRuleFieldMapper implements RuleFieldMapper {
      * @see com.openexchange.mailfilter.json.ajax.json.RuleFieldMapper#setAttribute(com.openexchange.jsieve.commands.Rule, java.lang.Object)
      */
     @Override
-    public void setAttribute(Rule rule, Object attribute) throws JSONException, SieveException, OXException {
+    public void setAttribute(Rule rule, Object attribute, ServerSession session) throws JSONException, SieveException, OXException {
         if (isNull(rule)) {
             throw new SieveException("There is no if command where the action command can be applied to in rule " + rule);
         }
@@ -180,7 +183,7 @@ public class ActionCommandRuleFieldMapper implements RuleFieldMapper {
             if (parser == null) {
                 throw new JSONException("Unknown action command while creating object: " + id);
             }
-            actionCommands.add(parser.parse(object));
+            actionCommands.add(parser.parse(object, session));
         }
 
         // Sanitize/sort them
