@@ -56,6 +56,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.jsieve.commands.Rule;
 import com.openexchange.jsieve.commands.RuleComment;
 import com.openexchange.mailfilter.json.ajax.json.fields.RuleField;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link RuleNameRuleFieldMapper}
@@ -73,7 +74,7 @@ public class RuleNameRuleFieldMapper implements RuleFieldMapper {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.RuleFieldMapper#getAttributeName()
      */
     @Override
@@ -83,7 +84,7 @@ public class RuleNameRuleFieldMapper implements RuleFieldMapper {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.RuleFieldMapper#isNull(com.openexchange.jsieve.commands.Rule)
      */
     @Override
@@ -94,7 +95,7 @@ public class RuleNameRuleFieldMapper implements RuleFieldMapper {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.RuleFieldMapper#getAttribute(com.openexchange.jsieve.commands.Rule)
      */
     @Override
@@ -102,18 +103,18 @@ public class RuleNameRuleFieldMapper implements RuleFieldMapper {
         if (isNull(rule)) {
             return JSONObject.NULL;
         }
-        
+
         RuleComment ruleComment = rule.getRuleComment();
         return ruleComment.getRulename();
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.RuleFieldMapper#setAttribute(com.openexchange.jsieve.commands.Rule, java.lang.Object)
      */
     @Override
-    public void setAttribute(Rule rule, Object attribute) throws JSONException, SieveException, OXException {
+    public void setAttribute(Rule rule, Object attribute, ServerSession session) throws JSONException, SieveException, OXException {
         RuleComment ruleComment = rule.getRuleComment();
         if (null != ruleComment) {
             ruleComment.setRulename((String) attribute);
