@@ -51,6 +51,7 @@ package com.openexchange.jsieve.commands.test;
 
 import java.util.Hashtable;
 import java.util.List;
+import com.openexchange.jsieve.commands.JSONMatchType;
 
 /**
  * {@link ITestCommand}
@@ -58,7 +59,7 @@ import java.util.List;
  * @author <a href="mailto:felix.marx@open-xchange.com">Felix Marx</a>
  * @since v7.8.0
  */
-public interface ITestCommand {
+public interface ITestCommand extends ICommand {
 
     /**
      * @return
@@ -80,16 +81,6 @@ public interface ITestCommand {
      */
     int getMaxNumberOfArguments();
 
-    /**
-     * @return
-     */
-    String getCommandName();
-
-    /**
-     * @return
-     */
-    String getRequired();
-
     /**
      * @return
      */
@@ -98,7 +89,7 @@ public interface ITestCommand {
     /**
      * @return
      */
-    List<String[]> getJsonMatchTypes();
+    List<JSONMatchType> getJsonMatchTypes();
 
     /**
      * @return
