@@ -361,7 +361,7 @@ public final class SieveTextFilter {
         final Map<String, List<Rule>> flagged = new HashMap<String, List<Rule>>();
         ClientRulesAndRequire retval = new ClientRulesAndRequire(requires, rules);
         // The flag is checked here because if no flag is given we can omit some checks which increases performance
-        if (!Strings.isEmpty(flag)) {
+        if (Strings.isNotEmpty(flag)) {
             for (final Rule rule : rules) {
                 final RuleComment ruleComment = rule.getRuleComment();
                 final RequireCommand requireCommand = rule.getRequireCommand();
@@ -792,6 +792,8 @@ public final class SieveTextFilter {
         }
     }
 
+    private static final String TEXT_TAG = "text:";
+
     /**
      * This method is used to remove the comments only at those places at which
      * they are used as comments not in multi line texts for example
@@ -826,7 +828,7 @@ public final class SieveTextFilter {
                 nextChar = false;
                 i++;
             } else if (!commentRemoved && !comment && c == 't') {
-                if ("text:".equals(sb.substring(i, i + 5))) {
+                if (((i + TEXT_TAG.length()) <= sb.length()) && TEXT_TAG.equals(sb.substring(i, i + TEXT_TAG.length()))) {
                     dontParse = true;
                 }
                 nextChar = false;
